import array, time
from machine import Pin,PWM
import rp2

NUM_LEDS = 1
PIN_NUM = 13
pwm = PWM(Pin(6))
pwm.freq(1000)

@rp2.asm_pio(sideset_init=rp2.PIO.OUT_LOW, out_shiftdir=rp2.PIO.SHIFT_LEFT, autopull=True, pull_thresh=24)
def ws2812():
    T1 = 2
    T2 = 5
    T3 = 3
    wrap_target()
    label("bitloop")
    out(x, 1)               .side(0)    [T3 - 1]
    jmp(not_x, "do_zero")   .side(1)    [T1 - 1]
    jmp("bitloop")          .side(1)    [T2 - 1]
    label("do_zero")
    nop()                   .side(0)    [T2 - 1]
    wrap()
class NeoPixel(object):
    def __init__(self,pin=PIN_NUM,num=NUM_LEDS,brightness=0.8):
        self.pin=pin
        self.num=num
        self.brightness = brightness
        # Create the StateMachine with the ws2812 program, outputting on pin
        self.sm = rp2.StateMachine(0, ws2812, freq=8_000_000, sideset_base=Pin(PIN_NUM))

        # Start the StateMachine, it will wait for data on its FIFO.
        self.sm.active(1)

        # Display a pattern on the LEDs via an array of LED RGB values.
        self.ar = array.array("I", [0 for _ in range(self.num)])   
        self.ch1 = Pin(21,Pin.OUT)
        self.ch2 = Pin(20,Pin.OUT)
        self.ch3 = Pin(19,Pin.OUT)
        self.ch4 = Pin(18,Pin.OUT)
        self.ch5 = Pin(17,Pin.OUT)
        self.ch6 = Pin(16,Pin.OUT)
        self.ch7 = Pin(15,Pin.OUT)
        self.ch8 = Pin(14,Pin.OUT)
    ##########################################################################
    def pixels_show(self):
        dimmer_ar = array.array("I", [0 for _ in range(self.num)])
        for i,c in enumerate(self.ar):
            r = int(((c >> 8) & 0xFF) * self.brightness)
            g = int(((c >> 16) & 0xFF) * self.brightness)
            b = int((c & 0xFF) * self.brightness)
            dimmer_ar[i] = (g<<16) + (r<<8) + b
        self.sm.put(dimmer_ar, 8)

    def pixels_set(self, i, color):
        self.ar[i] = (color[1]<<16) + (color[0]<<8) + color[2]
     
    def wheel(self, pos):
        # Input a value 0 to 31 to get a color value.
        # The colours are a transition r - g - b - back to r.
        if pos < 0 or pos > 255:
            return (0, 0, 0)
        if pos < 85:
            return (255 - pos * 3, pos * 3, 0)
        if pos < 170:
            pos -= 85
            return (0, 255 - pos * 3,pos * 3)
        pos -= 170
        return (pos * 3, 0, 255 - pos * 3)
     
     
    def rainbow_cycle(self, wait):
        for j in range(256):
            for i in range(self.num):
                rc_index = (i * 256 // self.num) + j
                self.pixels_set(i, self.wheel(rc_index & 255))
            self.pixels_show()
            time.sleep(wait)
    def Relay_CHx(self,n,switch): 
        if switch == 1:
            n.high()
        else:
            n.low()

if __name__=='__main__':
    strip = NeoPixel()
    duty = 0
    direction = 1
    while True:
        print("high")
        strip.Relay_CHx(strip.ch1,1)
        strip.Relay_CHx(strip.ch2,1)
        strip.Relay_CHx(strip.ch3,1)
        strip.Relay_CHx(strip.ch4,1)
        strip.Relay_CHx(strip.ch5,1)
        strip.Relay_CHx(strip.ch6,1)
        strip.Relay_CHx(strip.ch7,1)
        strip.Relay_CHx(strip.ch8,1)
        time.sleep(1)
        strip.rainbow_cycle(0.01)
        for _ in range(8 * 256):
            duty += direction
            if duty > 255:
                duty = 255
                direction = -1
            elif duty < 0:
                duty = 0
                direction = 1
            pwm.duty_u16(duty * duty)
            time.sleep(0.001)
        print("low")
        strip.Relay_CHx(strip.ch1,0)
        strip.Relay_CHx(strip.ch2,0)
        strip.Relay_CHx(strip.ch3,0)
        strip.Relay_CHx(strip.ch4,0)
        strip.Relay_CHx(strip.ch5,0)
        strip.Relay_CHx(strip.ch6,0)
        strip.Relay_CHx(strip.ch7,0)
        strip.Relay_CHx(strip.ch8,0)
        time.sleep(1)
